@@ -1,24 +1,9 @@
 """AMQP Channels."""
 # Copyright (C) 2007-2008 Barry Pederson <bp@barryp.org>
-#
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
 from __future__ import absolute_import, unicode_literals
 
 import logging
 import socket
-
 from collections import defaultdict
 from warnings import warn
 
@@ -26,10 +11,9 @@ from vine import ensure_promise
 
 from . import spec
 from .abstract_channel import AbstractChannel
-from .exceptions import (
-    ChannelError, ConsumerCancelled,
-    RecoverableChannelError, RecoverableConnectionError, error_for_code,
-)
+from .exceptions import (ChannelError, ConsumerCancelled,
+                         RecoverableChannelError, RecoverableConnectionError,
+                         error_for_code)
 from .five import Queue
 from .protocol import queue_declare_ok_t
 
